NLSL: stdio.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

stdio.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/11/15
2 c*********************************************************************
3 c
4 c STDIO: declarations of standard I/O parameters
5 c
6 c Notes:
7 c 1) The parameters define here are used as
8 c
9 c luttyi : logical unit for terminal input
10 c luttyo : logical unit for terminal output
11 c lulog : logical unit for log file
12 c lutrc : logical unit for trace file
13 c ludisk : logical unit for other disk files
14 c
15 c NOTE: The units that will be used for additional
16 c disk input depend on the mxfile parameter defined
17 c in "nlsdim.inc". If mxfile is greater than 1,
18 c units <ludisk+1>, <ludisk+2>, ... <ludisk+mxfile>
19 c are assumed to be available.
20 c
21 c 2) The appropriate values for these parameters are
22 c highly operating system and compiler dependent.
23 c
24 c*********************************************************************
25 c
26 module stdio
27 implicit none
28 c
29 integer, parameter :: lulog=4, luttyi=5, luttyo=6,
30 # lutrc=7, ludisk=8
31 c
32 integer, save :: lucmd, luecho, luout, hltcmd, hltfit, itrace
33 logical, save :: warn
34 c
35 end module stdio
stdio::luout
integer, save luout
Definition: stdio.f90:32
stdio::lucmd
integer, save lucmd
Definition: stdio.f90:32
stdio::hltcmd
integer, save hltcmd
Definition: stdio.f90:32
stdio::hltfit
integer, save hltfit
Definition: stdio.f90:32
stdio
Definition: stdio.f90:26
stdio::lutrc
integer, parameter lutrc
Definition: stdio.f90:29
stdio::lulog
integer, parameter lulog
Definition: stdio.f90:29
stdio::luecho
integer, save luecho
Definition: stdio.f90:32
stdio::ludisk
integer, parameter ludisk
Definition: stdio.f90:29
stdio::luttyo
integer, parameter luttyo
Definition: stdio.f90:29
stdio::luttyi
integer, parameter luttyi
Definition: stdio.f90:29
stdio::warn
logical, save warn
Definition: stdio.f90:33
stdio::itrace
integer, save itrace
Definition: stdio.f90:32